@@ -170,22 +170,22 @@ sub LoadDB {
 	my $self = shift; 
 	my $result = shift; 
 	my $dbname = shift; 
-	my %newdb = [];
+	my %db = [];
 	my $key ;
 	if (-e "$self->{Netpkg_dir}/$dbname" ) {
-		%newdb = %{ retrieve("$self->{Netpkg_dir}/$dbname") } ; 
+		%db = %{ retrieve("$self->{Netpkg_dir}/$dbname") } ; 
 		$$result = 0 ;
 	}else{
 		$$result = -1;
 	}
-	return \%newdb;
+	return \%db;
 }
 
 # Will parse the repository data to fill %db related fields
 # $href = $Netpkg->BuildDB
 sub BuildDB {
 	my $self = shift; 
-	my %newdb = [];
+	my %db = [];
 	my $soft;
 	my $desc;
 	my $package;
@@ -205,155 +205,155 @@ sub BuildDB {
 			$package="$1"; 
 			$package =~ /^(.*)-([^-]*)-[^-]*-([^-]*).t[glx]z$/;
 			$soft="$1"; 
-			@{$newdb{$soft}}[AVAILABLE_PKG] = "$package";	
-			@{$newdb{$soft}}[AVAILABLE_VERSION] = "$2";
-			@{$newdb{$soft}}[AVAILABLE_BUILD] = "$3";		
+			@{$db{$soft}}[AVAILABLE_PKG] = "$package";	
+			@{$db{$soft}}[AVAILABLE_VERSION] = "$2";
+			@{$db{$soft}}[AVAILABLE_BUILD] = "$3";		
 			next;
 		}
 		if ($_ =~ /PACKAGE LOCATION:\s*\.?\/?([^\s]*)\s*$/) { 
-			@{$newdb{$soft}}[PATH] = "$1";	
+			@{$db{$soft}}[PATH] = "$1";	
 
 			if ( $ZenStyle = 1 ) {
 				if ( 
-				@{$newdb{$soft}}[PATH] =~ /^l$/ || 
-				@{$newdb{$soft}}[PATH] =~ /.*\/l$/ 
+				@{$db{$soft}}[PATH] =~ /^l$/ || 
+				@{$db{$soft}}[PATH] =~ /.*\/l$/ 
 				) {
-					@{$newdb{$soft}}[CATEGORY] = decode('utf8',gettext("Runtime libraries"));
-					@{$newdb{$soft}}[CATEGORY_ICON] = "gnome-other";
+					@{$db{$soft}}[CATEGORY] = decode('utf8',gettext("Runtime libraries"));
+					@{$db{$soft}}[CATEGORY_ICON] = "gnome-other";
 				}elsif ( 
-				@{$newdb{$soft}}[PATH] =~ /^d$/ ||
-				@{$newdb{$soft}}[PATH] =~ /.*\/d$/ 
+				@{$db{$soft}}[PATH] =~ /^d$/ ||
+				@{$db{$soft}}[PATH] =~ /.*\/d$/ 
 				) {
-					@{$newdb{$soft}}[CATEGORY] = decode('utf8',gettext("Development libraries"));
-					@{$newdb{$soft}}[CATEGORY_ICON] = "development";
+					@{$db{$soft}}[CATEGORY] = decode('utf8',gettext("Development libraries"));
+					@{$db{$soft}}[CATEGORY_ICON] = "development";
 				}elsif ( 
-				@{$newdb{$soft}}[PATH] =~ /^x$/ ||
-				@{$newdb{$soft}}[PATH] =~ /.*\/x$/ 
+				@{$db{$soft}}[PATH] =~ /^x$/ ||
+				@{$db{$soft}}[PATH] =~ /.*\/x$/ 
 				) {
-					@{$newdb{$soft}}[CATEGORY] = decode('utf8',gettext("Xorg"));
-					@{$newdb{$soft}}[CATEGORY_ICON] = "xorg";
+					@{$db{$soft}}[CATEGORY] = decode('utf8',gettext("Xorg"));
+					@{$db{$soft}}[CATEGORY_ICON] = "xorg";
 				}elsif ( 
-				@{$newdb{$soft}}[PATH] =~ /^ap$/ ||
-				@{$newdb{$soft}}[PATH] =~ /.*\/ap$/
+				@{$db{$soft}}[PATH] =~ /^ap$/ ||
+				@{$db{$soft}}[PATH] =~ /.*\/ap$/
 				) {
-					@{$newdb{$soft}}[CATEGORY] = decode('utf8',gettext("Console Applications"));
-					@{$newdb{$soft}}[CATEGORY_ICON] = "utilities-terminal";
+					@{$db{$soft}}[CATEGORY] = decode('utf8',gettext("Console Applications"));
+					@{$db{$soft}}[CATEGORY_ICON] = "utilities-terminal";
 				}elsif ( 
-				@{$newdb{$soft}}[PATH] =~ /^xap$/ ||
-				@{$newdb{$soft}}[PATH] =~ /.*\/xap$/
+				@{$db{$soft}}[PATH] =~ /^xap$/ ||
+				@{$db{$soft}}[PATH] =~ /.*\/xap$/
 				) {
-					@{$newdb{$soft}}[CATEGORY] = decode('utf8',gettext("Graphical Applications"));
-					@{$newdb{$soft}}[CATEGORY_ICON] = "applications-graphics";
+					@{$db{$soft}}[CATEGORY] = decode('utf8',gettext("Graphical Applications"));
+					@{$db{$soft}}[CATEGORY_ICON] = "applications-graphics";
 				}elsif ( 
-				@{$newdb{$soft}}[PATH] =~ /.*\/g$/ 
+				@{$db{$soft}}[PATH] =~ /.*\/g$/ 
 				) {
-					@{$newdb{$soft}}[CATEGORY] = decode('utf8',gettext("Gnome Desktop"));
-					@{$newdb{$soft}}[CATEGORY_ICON] = "gnome-logo";
+					@{$db{$soft}}[CATEGORY] = decode('utf8',gettext("Gnome Desktop"));
+					@{$db{$soft}}[CATEGORY_ICON] = "gnome-logo";
 				}elsif ( 
-				@{$newdb{$soft}}[PATH] =~ /.*\/kde$/ 
+				@{$db{$soft}}[PATH] =~ /.*\/kde$/ 
 				) {
-					@{$newdb{$soft}}[CATEGORY] = decode('utf8',gettext("KDE Desktop"));
-					@{$newdb{$soft}}[CATEGORY_ICON] = "konqueror";
+					@{$db{$soft}}[CATEGORY] = decode('utf8',gettext("KDE Desktop"));
+					@{$db{$soft}}[CATEGORY_ICON] = "konqueror";
 				}elsif ( 
-				@{$newdb{$soft}}[PATH] =~ /^a$/ || 
-				@{$newdb{$soft}}[PATH] =~ /.*\/a$/ 
+				@{$db{$soft}}[PATH] =~ /^a$/ || 
+				@{$db{$soft}}[PATH] =~ /.*\/a$/ 
 				) {
-					@{$newdb{$soft}}[CATEGORY] = decode('utf8',gettext("System"));
-					@{$newdb{$soft}}[CATEGORY_ICON] = "applications-system";
+					@{$db{$soft}}[CATEGORY] = decode('utf8',gettext("System"));
+					@{$db{$soft}}[CATEGORY_ICON] = "applications-system";
 				}elsif ( 
-				@{$newdb{$soft}}[PATH] =~ /^locale$/ || 
-				@{$newdb{$soft}}[PATH] =~ /.*\/locale$/ 
+				@{$db{$soft}}[PATH] =~ /^locale$/ || 
+				@{$db{$soft}}[PATH] =~ /.*\/locale$/ 
 				) {
-					@{$newdb{$soft}}[CATEGORY] = decode('utf8',gettext("Localization"));
-					@{$newdb{$soft}}[CATEGORY_ICON] = "preferences-desktop-locale";
+					@{$db{$soft}}[CATEGORY] = decode('utf8',gettext("Localization"));
+					@{$db{$soft}}[CATEGORY_ICON] = "preferences-desktop-locale";
 				}elsif ( 
-				@{$newdb{$soft}}[PATH] =~ /^games$/ || 
-				@{$newdb{$soft}}[PATH] =~ /.*\/games$/ 
+				@{$db{$soft}}[PATH] =~ /^games$/ || 
+				@{$db{$soft}}[PATH] =~ /.*\/games$/ 
 				) {
-					@{$newdb{$soft}}[CATEGORY] = decode('utf8',gettext("Games"));
-					@{$newdb{$soft}}[CATEGORY_ICON] = "applications-games";
+					@{$db{$soft}}[CATEGORY] = decode('utf8',gettext("Games"));
+					@{$db{$soft}}[CATEGORY_ICON] = "applications-games";
 				}elsif ( 
-				@{$newdb{$soft}}[PATH] =~ /^n$/ || 
-				@{$newdb{$soft}}[PATH] =~ /.*\/n$/ ||
-				@{$newdb{$soft}}[PATH] =~ /^s$/ || 
-				@{$newdb{$soft}}[PATH] =~ /.*\/s$/ 
+				@{$db{$soft}}[PATH] =~ /^n$/ || 
+				@{$db{$soft}}[PATH] =~ /.*\/n$/ ||
+				@{$db{$soft}}[PATH] =~ /^s$/ || 
+				@{$db{$soft}}[PATH] =~ /.*\/s$/ 
 				) {
-					@{$newdb{$soft}}[CATEGORY] = decode('utf8',gettext("Network"));
-					@{$newdb{$soft}}[CATEGORY_ICON] = "applications-internet";
+					@{$db{$soft}}[CATEGORY] = decode('utf8',gettext("Network"));
+					@{$db{$soft}}[CATEGORY_ICON] = "applications-internet";
 				}else{
-					@{$newdb{$soft}}[CATEGORY] = decode('utf8',gettext("Misc"));
-					@{$newdb{$soft}}[CATEGORY_ICON] = "applications-other";
+					@{$db{$soft}}[CATEGORY] = decode('utf8',gettext("Misc"));
+					@{$db{$soft}}[CATEGORY_ICON] = "applications-other";
 				}
 				
-				#if ( @{$newdb{$soft}}[PATH] =~ /^extra.*/ ) {
-				#	@{$newdb{$soft}}[CATEGORY] = "Extra ".@{$newdb{$soft}}[CATEGORY] ;
+				#if ( @{$db{$soft}}[PATH] =~ /^extra.*/ ) {
+				#	@{$db{$soft}}[CATEGORY] = "Extra ".@{$db{$soft}}[CATEGORY] ;
 				#}
 				
 				
-				@{$newdb{$soft}}[SORTSTRING] = @{$newdb{$soft}}[CATEGORY]."/".$package;
+				@{$db{$soft}}[SORTSTRING] = @{$db{$soft}}[CATEGORY]."/".$package;
 				
 			}else{
-				@{$newdb{$soft}}[CATEGORY] = @{$newdb{$soft}}[PATH] ;
-				if ( @{$newdb{$soft}}[PATH] =~ /^extra.*/ ) {
-					@{$newdb{$soft}}[SORTSTRING] = "y".@{$newdb{$soft}}[CATEGORY]."/".$package;
+				@{$db{$soft}}[CATEGORY] = @{$db{$soft}}[PATH] ;
+				if ( @{$db{$soft}}[PATH] =~ /^extra.*/ ) {
+					@{$db{$soft}}[SORTSTRING] = "y".@{$db{$soft}}[CATEGORY]."/".$package;
 				}else{
-					@{$newdb{$soft}}[SORTSTRING] = @{$newdb{$soft}}[CATEGORY]."/".$package;
+					@{$db{$soft}}[SORTSTRING] = @{$db{$soft}}[CATEGORY]."/".$package;
 				}
 			}	
 			
 			next;
 		}	
 		if ($_ =~ /PACKAGE SIZE \(c.*:\s*(.*)\s*$/) { 
-			@{$newdb{$soft}}[SIZE_COMPRESSED] = "$1";	
+			@{$db{$soft}}[SIZE_COMPRESSED] = "$1";	
 			next;						
 		}			
 		if ($_ =~ /PACKAGE SIZE \(u.*:\s*(.*)\s*$/) { 
-			@{$newdb{$soft}}[SIZE_UNCOMPRESSED] = "$1";	
+			@{$db{$soft}}[SIZE_UNCOMPRESSED] = "$1";	
 			next;							
 		}														
 		if ($_ =~ /PACKAGE REQUIRED:\s*([^\s]*)\s*$/) { 
-			@{$newdb{$soft}}[DEPENDENCIES] = "$1";	
-			@{$newdb{$soft}}[DEPENDENCIES] =~ s/,/ /g ;
+			@{$db{$soft}}[DEPENDENCIES] = "$1";	
+			@{$db{$soft}}[DEPENDENCIES] =~ s/,/ /g ;
 			next;				
 		}
 		if ($_ =~ /PACKAGE REQUIRED:\s*([^\s]*)\s*$/) { 
-			@{$newdb{$soft}}[DEPENDENCIES] = "$1";	
-			@{$newdb{$soft}}[DEPENDENCIES] =~ s/,/ /g ;
+			@{$db{$soft}}[DEPENDENCIES] = "$1";	
+			@{$db{$soft}}[DEPENDENCIES] =~ s/,/ /g ;
 			next;				
 		}
 		if ($_ =~ /PACKAGE LIBS:\s*(.*)$/) { 
-			@{$newdb{$soft}}[LIBS] = "$1";	
-			@{$newdb{$soft}}[LIBS] =~ s/,/ /g ;
+			@{$db{$soft}}[LIBS] = "$1";	
+			@{$db{$soft}}[LIBS] =~ s/,/ /g ;
 			next;				
 		}				
-		# @{$newdb{$soft}}[DESCRIPTION] = "" if ( undef @{$newdb{$soft}}[DESCRIPTION] ) ;	
+		# @{$db{$soft}}[DESCRIPTION] = "" if ( undef @{$db{$soft}}[DESCRIPTION] ) ;	
 		while ($_ =~ /\Q${soft}\E:(.*)/) {
 			$desc = $1;
 			chomp $desc;
 			$desc =~ s/[\ \t]{2,}/ /g ;						
-			@{$newdb{$soft}}[DESCRIPTION] = @{$newdb{$soft}}[DESCRIPTION]." ".$desc;
+			@{$db{$soft}}[DESCRIPTION] = @{$db{$soft}}[DESCRIPTION]." ".$desc;
 			$_ = <SH>;
 		}
 
 		# Until we check local packages, everything is NEW
-		@{$newdb{$soft}}[INSTALLED_VERSION] = decode('utf8',gettext("not installed"));
-		@{$newdb{$soft}}[STATUS] = STATUS_NEW ;
+		@{$db{$soft}}[INSTALLED_VERSION] = decode('utf8',gettext("not installed"));
+		@{$db{$soft}}[STATUS] = STATUS_NEW ;
 		
 		# SELECTED PACKAGE BOOLEAN	
-		@{$newdb{$soft}}[SELECTED_AS_PKG] = 0; 
+		@{$db{$soft}}[SELECTED_AS_PKG] = 0; 
 		# SELECTED DEP BOOLEAN	
-		@{$newdb{$soft}}[SELECTED_AS_DEP] = 0; 
+		@{$db{$soft}}[SELECTED_AS_DEP] = 0; 
 		# DELETING REVERSE DEPS
-		@{$newdb{$soft}}[USED_BY] = "";
+		@{$db{$soft}}[USED_BY] = "";
 		
 		if ( defined $Blacklist{$soft} ) {
-			@{$newdb{$soft}}[BLACKLISTED] = 1 ;
+			@{$db{$soft}}[BLACKLISTED] = 1 ;
 		}
 			
 	}
 	close(FH); 	
 
-	return \%newdb;
+	return \%db;
 }
 
 
@@ -366,7 +366,6 @@ sub CheckInstalledPkgs {
 	my $fh;
 	my ($package,$soft,$version,$build,$desc,$meta);
 
-	my %localdb = [];
 	opendir(DH, "$self->{Package_logs}") || return -1 ;
 	foreach (sort readdir(DH)) {
 		
@@ -436,7 +435,7 @@ sub CheckInstalledPkgs {
 		close(FH);	
 	}
 	closedir(DH); 
-	return 0;
+	return \%db;;
 }
 
 
